@@ -8,7 +8,7 @@
 package Lingua::Interset::Tagset::CS::Ajka;
 use strict;
 use warnings;
-our $VERSION = '3.001';
+our $VERSION = '3.002';
 
 use utf8;
 use open ':utf8';
@@ -179,7 +179,7 @@ sub _create_atoms
             'xO' => ['numtype' => 'ord', 'pos' => 'adj|adv'],
             # Generic numeral.
             # Examples: dvoje, dvojí, oboje, obojí, troje, trojí, několikerý
-            'xR' => ['numtype' => 'gen', 'pos' => 'adj'],
+            'xR' => ['numtype' => 'sets|mult', 'pos' => 'adj'],
             # Demonstrative numeral.
             # Examples: tolik
             # ("tolik" could be described as demonstrative cardinal numeral.
@@ -196,7 +196,8 @@ sub _create_atoms
             { 'prontype' => { 'dem' => 'xD',
                               '@'   => { 'numtype' => { 'card' => 'xC',
                                                         'ord'  => 'xO',
-                                                        'gen'  => 'xR' }}}}
+                                                        'sets' => 'xR',
+                                                        'mult' => 'xR' }}}}
     );
     $atoms{xk6} = $self->create_atom
     (
@@ -2895,7 +2896,7 @@ Lingua::Interset::Tagset::CS::Ajka - Driver for the tagset of the Czech morpholo
 
 =head1 VERSION
 
-version 3.001
+version 3.002
 
 =head1 SYNOPSIS
 
